Enum Event

enum Event

Input event

Variants

Any

Wildcard. Useful if you want to filter out some keys.

KeySeq(Vec<crate::KeyEvent>)

Key sequence

Mouse()

TODO Mouse event

Implementations

impl Event

fn get(self: &Self, i: usize) -> Option<&KeyEvent>

Return ith key event

impl Clone for Event

fn clone(self: &Self) -> Event

impl Debug for Event

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Event

impl Freeze for Event

impl From for Event

fn from(k: KeyEvent) -> Self

impl Hash for Event

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for Event

fn eq(self: &Self, other: &Event) -> bool

impl RefUnwindSafe for Event

impl Send for Event

impl StructuralPartialEq for Event

impl Sync for Event

impl TrieKey for Event

fn encode_bytes(self: &Self) -> Vec<u8>

impl Unpin for Event

impl UnsafeUnpin for Event

impl UnwindSafe for Event

impl<T> Any for Event

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Event

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Event

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Event

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Event

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Event

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Event

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Event

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Event

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>