Struct Modifiers
struct Modifiers(_)
The set of modifier keys that were triggered along with a key press.
Implementations
impl Modifiers
const fn empty() -> SelfGet a flags value with all bits unset.
const fn all() -> SelfGet a flags value with all known bits set.
const fn bits(self: &Self) -> u8Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
const fn from_bits(bits: u8) -> Option<Self>Convert from a bits value.
This method will return
Noneif any unknown bits are set.const fn from_bits_truncate(bits: u8) -> SelfConvert from a bits value, unsetting any unknown bits.
const fn from_bits_retain(bits: u8) -> SelfConvert from a bits value exactly.
fn from_name(name: &str) -> Option<Self>Get a flags value with the bits of a flag with the given name set.
This method will return
Noneifnameis empty or doesn't correspond to any named flag.const fn is_empty(self: &Self) -> boolWhether all bits in this flags value are unset.
const fn is_all(self: &Self) -> boolWhether all known bits in this flags value are set.
const fn intersects(self: &Self, other: Self) -> boolWhether any set bits in a source flags value are also set in a target flags value.
const fn contains(self: &Self, other: Self) -> boolWhether all set bits in a source flags value are also set in a target flags value.
fn insert(self: &mut Self, other: Self)The bitwise or (
|) of the bits in two flags values.fn remove(self: &mut Self, other: Self)The intersection of a source flags value with the complement of a target flags value (
&!).This method is not equivalent to
self & !otherwhenotherhas unknown bits set.removewon't truncateother, but the!operator will.fn toggle(self: &mut Self, other: Self)The bitwise exclusive-or (
^) of the bits in two flags values.fn set(self: &mut Self, other: Self, value: bool)Call
insertwhenvalueistrueorremovewhenvalueisfalse.const fn intersection(self: Self, other: Self) -> SelfThe bitwise and (
&) of the bits in two flags values.const fn union(self: Self, other: Self) -> SelfThe bitwise or (
|) of the bits in two flags values.const fn difference(self: Self, other: Self) -> SelfThe intersection of a source flags value with the complement of a target flags value (
&!).This method is not equivalent to
self & !otherwhenotherhas unknown bits set.differencewon't truncateother, but the!operator will.const fn symmetric_difference(self: Self, other: Self) -> SelfThe bitwise exclusive-or (
^) of the bits in two flags values.const fn complement(self: Self) -> SelfThe bitwise negation (
!) of the bits in a flags value, truncating the result.
impl Modifiers
const fn iter(self: &Self) -> Iter<Modifiers>Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
const fn iter_names(self: &Self) -> IterNames<Modifiers>Yield a set of contained named flags values.
This method is like
iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
impl Modifiers
impl Binary for Modifiers
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl BitAnd for Modifiers
fn bitand(self: Self, other: Self) -> SelfThe bitwise and (
&) of the bits in two flags values.
impl BitAndAssign for Modifiers
fn bitand_assign(self: &mut Self, other: Self)The bitwise and (
&) of the bits in two flags values.
impl BitOr for Modifiers
fn bitor(self: Self, other: Modifiers) -> SelfThe bitwise or (
|) of the bits in two flags values.
impl BitOrAssign for Modifiers
fn bitor_assign(self: &mut Self, other: Self)The bitwise or (
|) of the bits in two flags values.
impl BitXor for Modifiers
fn bitxor(self: Self, other: Self) -> SelfThe bitwise exclusive-or (
^) of the bits in two flags values.
impl BitXorAssign for Modifiers
fn bitxor_assign(self: &mut Self, other: Self)The bitwise exclusive-or (
^) of the bits in two flags values.
impl Clone for Modifiers
fn clone(self: &Self) -> Modifiers
impl Copy for Modifiers
impl Debug for Modifiers
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Modifiers
impl Extend for Modifiers
fn extend<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(self: &mut Self, iterator: T)The bitwise or (
|) of the bits in each flags value.
impl Flags for Modifiers
fn bits(self: &Self) -> u8fn from_bits_retain(bits: u8) -> Modifiers
impl Freeze for Modifiers
impl FromIterator for Modifiers
fn from_iter<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(iterator: T) -> SelfThe bitwise or (
|) of the bits in each flags value.
impl Hash for Modifiers
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl IntoIterator for Modifiers
fn into_iter(self: Self) -> <Self as >::IntoIter
impl LowerHex for Modifiers
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Not for Modifiers
fn not(self: Self) -> SelfThe bitwise negation (
!) of the bits in a flags value, truncating the result.
impl Octal for Modifiers
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl PartialEq for Modifiers
fn eq(self: &Self, other: &Modifiers) -> bool
impl PublicFlags for Modifiers
impl RefUnwindSafe for Modifiers
impl Send for Modifiers
impl StructuralPartialEq for Modifiers
impl Sub for Modifiers
fn sub(self: Self, other: Self) -> SelfThe intersection of a source flags value with the complement of a target flags value (
&!).This method is not equivalent to
self & !otherwhenotherhas unknown bits set.differencewon't truncateother, but the!operator will.
impl SubAssign for Modifiers
fn sub_assign(self: &mut Self, other: Self)The intersection of a source flags value with the complement of a target flags value (
&!).This method is not equivalent to
self & !otherwhenotherhas unknown bits set.differencewon't truncateother, but the!operator will.
impl Sync for Modifiers
impl Unpin for Modifiers
impl UnsafeUnpin for Modifiers
impl UnwindSafe for Modifiers
impl UpperHex for Modifiers
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Modifiers
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Modifiers
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Modifiers
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Modifiers
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Modifiers
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Modifiers
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Modifiers
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Modifiers
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Modifiers
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>