pub struct FilenameCompleter { /* fields omitted */ }
A Completer for file and folder names.
Takes the currently edited line with the cursor position and
returns the start position and the completion candidates for the
partial path to be completed.
Specific completion candidate.
Takes the currently edited line with the cursor position and
returns the start position and the completion candidates for the
partial word to be completed. Read more
Updates the edited line with the elected candidate.
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.