Editor

Struct Editor 

pub struct Editor<H: Helper, I: History> { /* private fields */ }
Line editor

Implementations

Source

impl<H: Helper> Editor<H, DefaultHistory>

pub fn new() -> Result<Self>

Create an editor with the default configuration

pub fn with_config(config: Config) -> Result<Self>

Create an editor with a specific configuration.

Source

impl<H: Helper, I: History> Editor<H, I>

pub fn with_history(config: Config, history: I) -> Result<Self>

Create an editor with a custom history impl.

pub fn readline<P: Prompt + ?Sized>(&mut self, prompt: &P) -> Result<String>

This method will read a line from STDIN and will display a prompt.

prompt should not be styled (in case the terminal doesn’t support ANSI) directly: use Highlighter::highlight_prompt instead.

It uses terminal-style interaction if stdin is connected to a terminal. Otherwise (e.g., if stdin is a pipe or the terminal is not supported), it uses file-style interaction.

pub fn readline_with_initial<P: Prompt + ?Sized>( &mut self, prompt: &P, initial: (&str, &str), ) -> Result<String>

This function behaves in the exact same manner as Editor::readline, except that it pre-populates the input area.

The text that resides in the input area is given as a 2-tuple. The string on the left of the tuple is what will appear to the left of the cursor and the string on the right is what will appear to the right of the cursor.

pub fn load_history<P: AsRef<Path> + ?Sized>(&mut self, path: &P) -> Result<()>

Load the history from the specified file.

pub fn save_history<P: AsRef<Path> + ?Sized>(&mut self, path: &P) -> Result<()>

Save the history in the specified file.

pub fn append_history<P: AsRef<Path> + ?Sized>( &mut self, path: &P, ) -> Result<()>

Append new entries in the specified file.

pub fn add_history_entry<S: AsRef<str> + Into<String>>( &mut self, line: S, ) -> Result<bool>

Add a new entry in the history.

pub fn clear_history(&mut self) -> Result<()>

Clear history.

pub fn history_mut(&mut self) -> &mut I

Return a mutable reference to the history object.

pub fn history(&self) -> &I

Return an immutable reference to the history object.

pub fn set_helper(&mut self, helper: Option<H>)

Register a callback function to be called for tab-completion or to show hints to the user at the right of the prompt.

pub fn helper_mut(&mut self) -> Option<&mut H>

Return a mutable reference to the helper.

pub fn helper(&self) -> Option<&H>

Return an immutable reference to the helper.

pub fn bind_sequence<E: Into<Event>, R: Into<EventHandler>>( &mut self, key_seq: E, handler: R, ) -> Option<EventHandler>

Available on crate feature custom-bindings only.

Bind a sequence to a command.

pub fn unbind_sequence<E: Into<Event>>( &mut self, key_seq: E, ) -> Option<EventHandler>

Available on crate feature custom-bindings only.

Remove a binding for the given sequence.

pub fn iter<'a>( &'a mut self, prompt: &'a str, ) -> impl Iterator<Item = Result<String>> + 'a

Returns an iterator over edited lines. Iterator ends at EOF.

let mut rl = rustyline::DefaultEditor::new()?;
for readline in rl.iter("> ") {
    match readline {
        Ok(line) => {
            println!("Line: {}", line);
        }
        Err(err) => {
            println!("Error: {:?}", err);
            break;
        }
    }
}
pub fn dimensions(&mut self) -> Option<(u16, u16)>

If output stream is a tty, this function returns its width and height as a number of characters.

pub fn clear_screen(&mut self) -> Result<()>

Clear the screen.

pub fn create_external_printer( &mut self, ) -> Result<<PosixTerminal as Term>::ExternalPrinter>

Create an external printer

pub fn set_cursor_visibility( &mut self, visible: bool, ) -> Result<Option<<PosixTerminal as Term>::CursorGuard>>

Change cursor visibility