Trait ConditionalEventHandler

trait ConditionalEventHandler: Send + Sync

May behave differently depending on:

Required Methods

fn handle(self: &Self, evt: &Event, n: RepeatCount, positive: bool, ctx: &EventContext<'_>) -> Option<Cmd>

Takes the current input state and returns the command to be performed or None to perform the default one.